## Ansættelseskontrakt

Mellem undertegnede

<company-name>Grønt Helbred A/S
CVR-nr.: 30249876</company-name>

<location>Torvegade 48, st., 4720 Præstø (herefter kaldet virksomheden)</location>

og medundertegnede

## Nanna Jørgensen  
Holmbladsgade 79, 3. mf., 9520 Skørping  
(herefter kaldet medarbejderen)

indgås følgende ansættelsesaftale:

<start-date>
## [SECTION-IDX]. Tiltrædelse

Medarbejderen tiltræder stillingen med virkning fra den 15. juli 2024.
</start-date>

<location>
## [SECTION-IDX]. Arbejdssted

Arbejdsstedet vil som udgangspunkt være på Torvegade 48, 1., 5792 Årslev.  
Virksomheden kan dog, i nødvendigt omfang og med forudgående varsel, pålægge arbejde på andre steder i virksomheden.
</location>

<title>
## [SECTION-IDX]. Stillingsbetegnelse

Medarbejderen ansættes i stillingen som Klinikassistent.
</title>

## [SECTION-IDX]. Arbejdsopgaver

Medarbejderens primære opgaver vil være:

- Assistere tandlæger i klinikken.
- Modtage og servicere patienter.
- Sterilisering og håndtering af klinikkens udstyr.
- Administrative opgaver i forbindelse med klinikkens drift.

Arbejdsopgaverne kan til enhver tid ændres og tilpasses virksomhedens behov.

<trial-period>
Der er ikke aftalt nogen prøvetid i dette ansættelsesforhold.
</trial-period>

<salary>
## [SECTION-IDX]. Løn

Den årlige løn udgør 347.000 kr. brutto (før skat, pension og lovpligtige bidrag).  
Lønnen udbetales bagud månedsvis med 28.916 kr. brutto, indsættes på medarbejderens oplyste konto, sidste hverdag i måneden.

Lønforhold revideres årligt.
</salary>

<pension>
## [SECTION-IDX]. Pension

Medarbejderen er omfattet af en pensionsordning gennem PFA Pension.  
Virksomheden indbetaler 6,5% af den pensionsgivende løn, og medarbejderen indbetaler 3% af samme.  
Beløbene indbetales sammen med lønudbetalingen.
</pension>

<social-security>
## [SECTION-IDX]. Sociale sikringsbidrag

Virksomheden indbetaler alle lovpligtige sociale sikringsbidrag, herunder ATP, barselsfonden samt øvrige relevante bidrag i henhold til gældende dansk lovgivning.
</social-security>

<work-time>
## [SECTION-IDX]. Arbejdstid

Den gennemsnitlige ugentlige arbejdstid udgør 32 timer fordelt på ugens hverdage, eksklusive frokostpause.  
Arbejdstiden placeres efter nærmere aftale med virksomheden og under hensyntagen til klinikkens åbningstider.
</work-time>

<holiday>
## [SECTION-IDX]. Ferie

Medarbejderen har ret til ferie og feriegodtgørelse efter ferielovens bestemmelser.  
Det særlige ferietillæg på 2,48% af den ferieberettigede løn udbetales i forbindelse med ferieafholdelse.
</holiday>

<extra-holiday>
## [SECTION-IDX]. Feriefridage

Ansættelsen giver ikke ret til ekstra feriefridage ud over de lovbestemte ferieuger.
</extra-holiday>

<training>
## [SECTION-IDX]. Efteruddannelse

Medarbejderen har ret til relevant efteruddannelse, hvor det er foreneligt med virksomhedens drift og i overensstemmelse med overenskomsten.  
Behov og muligheder for efteruddannelse aftales løbende mellem medarbejder og virksomhed.
</training>

<illness>
## [SECTION-IDX]. Sygdom

Ved sygdom skal medarbejderen underrette virksomheden hurtigst muligt.  
Efter 3 dages fravær kan dokumentation for sygdom kræves via lægeerklæring, for hvilken virksomheden afholder udgiften.  
Medarbejderen oppebærer sin sædvanlige løn under sygdom.
</illness>

<parental-leave>
## [SECTION-IDX]. Graviditet, barsel, forældreorlov og barns sygdom

Medarbejderen er berettiget til orlov samt økonomiske ydelser i henhold til barselsloven og virksomhedens politik.

Virksomheden betaler fuld løn til mor i følgende perioder:
- 4 uger før forventet fødsel
- 14 uger efter fødsel

Virksomheden betaler fuld løn til far/medmor i:
- 2 uger efter barnets fødsel

Derudover har medarbejderen ret til fri med løn i op til 2 dage pr. kalenderår ved barns sygdom.
</parental-leave>

## [SECTION-IDX]. Fortrolighed

Medarbejderen er underlagt tavshedspligt under og efter ansættelsen, hvad angår alle oplysninger om virksomheden og dens forhold, som ikke er offentligt kendte eller bør anses som forretningshemmeligheder.

<termination>
## [SECTION-IDX]. Opsigelse

Ansættelsesforholdet kan af begge parter opsiges med 30 dages varsel til udløbet af en måned.  
Såfremt funktionærloven eller overenskomsten stiller medarbejderen bedre, er det disse regler, der gælder.

Opsigelsen skal ske skriftligt.
</termination>

<collective-agreement>
## [SECTION-IDX]. Overenskomst

Ansættelsesforholdet er omfattet af Tandlægeforeningens overenskomst samt gældende aftaler inden for området.
</collective-agreement>

## [SECTION-IDX]. Retsgrundlag

Ansættelsen er omfattet af dansk ret, herunder funktionær- og ferieloven, såfremt ansættelsesvilkårene ikke måtte stille medarbejderen bedre end disse lovregler.

Præstø, den 13. juni 2024

Medarbejderen: _____________________________________

Virksomheden: _____________________________________